<?php # $Id: serendipity_lang_is.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation by rn Arnarson <orn@arnarson.net>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-1');
@define('SQL_CHARSET', 'latin1');
@define('DATE_LOCALES', 'is_IS.ISO-8859-1, is_IS.ISO8859-1, icelandic, is, is_IS');
@define('DATE_FORMAT_ENTRY', '%A, %e. %B %Y');
@define('DATE_FORMAT_SHORT', '%d.%m.%y %H:%M');
@define('WYSIWYG_LANG', 'en');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '.');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Stjrnbor Serendipity');
@define('HAVE_TO_BE_LOGGED_ON', ' arft a vera skrur inn til a skoa essa su');
@define('WRONG_USERNAME_OR_PASSWORD', ' virist hafa slegi inn rangt notandanafn ea lykilor');
@define('APPEARANCE', 'tlit');
@define('MANAGE_STYLES', 'Breyta tliti');
@define('CONFIGURE_PLUGINS', 'Stilla vibtur');
@define('CONFIGURATION', 'Stillingar');
@define('BACK_TO_BLOG', 'Aftur  bloggi');
@define('LOGIN', 'Skr inn');
@define('LOGOUT', 'Skr t');
@define('LOGGEDOUT', 'tskrur.');
@define('CREATE', 'Ba til');
@define('SAVE', 'Vista');
@define('NAME', 'Nafn');
@define('CREATE_NEW_CAT', 'Ba til njan flokk');
@define('I_WANT_THUMB', 'g vil nota snishorn  frslunni.');
@define('I_WANT_BIG_IMAGE', 'g vil nota strri myndina  frslunni.');
@define('I_WANT_NO_LINK', ' g vil birta etta sem mynd');
@define('I_WANT_IT_TO_LINK', 'g vil birta etta sem hlekk  essa sl:');
@define('BACK', 'Til baka');
@define('FORWARD', 'fram');
@define('ANONYMOUS', 'Nafnlaus');
@define('NEW_TRACKBACK_TO', 'N tilvsun ger ');
@define('NEW_COMMENT_TO', 'N athugasemd send ');
@define('RECENT', 'Nlegt...');
@define('OLDER', 'Eldra...');
@define('DONE', 'Bin');
@define('WELCOME_BACK', 'Velkomin(n) aftur,');
@define('TITLE', 'Fyrirsgn');
@define('DESCRIPTION', 'Lsing');
@define('PLACEMENT', 'Stasetning');
@define('DELETE', 'Eya');
@define('SAVE', 'Vista');
@define('UP', 'Upp');
@define('DOWN', 'Niur');
@define('ENTRIES', 'frslur');
@define('NEW_ENTRY', 'Nja frslu');
@define('EDIT_ENTRIES', 'Breyta frslum');
@define('CATEGORIES', 'Flokkar');
@define('WARNING_THIS_BLAHBLAH', "VAR:\\netta gti teki langan tma ef a eru margar myndir n snishorna.");
@define('CREATE_THUMBS', 'Endurvinna snishorn');
@define('MANAGE_IMAGES', 'Breyta myndum');
@define('NAME', 'Nafn');
@define('EMAIL', 'Netfang');
@define('HOMEPAGE', 'Heimasa');
@define('COMMENT', 'Athugasemd');
@define('REMEMBER_INFO', 'Muna essar upplsingar? ');
@define('SUBMIT_COMMENT', 'Skr athugasemd');
@define('NO_ENTRIES_TO_PRINT', 'Engar frslur til a sna.');
@define('COMMENTS', 'Athugasemdir');
@define('ADD_COMMENT', 'Bta vi athugasemd');
@define('NO_COMMENTS', 'Engar athugasemdir.');
@define('POSTED_BY', '');
@define('ON', 'ann');
@define('A_NEW_COMMENT_BLAHBLAH', 'N athugasemd hefur veri send  bloggi itt, "%s",  frslunni "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'N tilvsun hefur veri ger  bloggfrsluna na, "%s".');
@define('NO_CATEGORY', 'Enginn flokkur');
@define('ENTRY_BODY', 'Innihald frslu');
@define('EXTENDED_BODY', 'Aukainnihald');
@define('CATEGORY', 'Flokkur');
@define('EDIT', 'Breyta');
@define('NO_ENTRIES_BLAHBLAH', 'Engar frslur fundnar fyrir fyrirspurn %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Leit n a %s skilai %s niurstum:');
@define('IMAGE', 'Mynd');
@define('ERROR_FILE_NOT_EXISTS', 'Villa: Gamla skrarnafni er ekki til!');
@define('ERROR_FILE_EXISTS', 'Villa: Nja skrarnafni er egar  notkun, veldu anna!');
@define('ERROR_SOMETHING', 'Villa: Eitthva er a.');
@define('ADDING_IMAGE', 'Bti vi mynd...');
@define('THUMB_CREATED_DONE', 'Snishorn bi til.<br>Loki.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Villa: Skrin er egar til  vlinni!');
@define('ERROR_UNKNOWN_NOUPLOAD', 'ekkt villa hefur komi upp, skr ekki vistu. Kannski var str skrarinnar meiri heldur en hmarksstrin sem netjnninn skilgreinir. Hafu samband vi jnustuailann inn ea breytti php.ini skrnni til a leyfa strri skrarflutninga.');
@define('GO', 'Go!');
@define('NEWSIZE', 'N str: ');
@define('RESIZE_BLAHBLAH', '<b>Breyta str %s</b>');
@define('ORIGINAL_SIZE', 'Upprunaleg str: <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hr getur  breytt str myndarinnar. Ef  vilt breyta str hennar  rttum hlutfllum, slu  inn eitthva gildi  annan tveggja reitanna og ttu  TAB takkann. -- Str eirra verur reiknu sjlfvirkt svo hlutfllin haldist rtt.</p>');
@define('QUICKJUMP_CALENDAR', 'QuickJump dagatal');
@define('QUICKSEARCH', 'Leita');
@define('SEARCH_FOR_ENTRY', 'Leita a frslu');
@define('ARCHIVES', 'Tmavlin');
@define('BROWSE_ARCHIVES', 'Vafra gamlar frslur eftir mnuum');
@define('TOP_REFERRER', 'Topp vsarar');
@define('SHOWS_TOP_SITES', 'Sna toppsur sem vsuu  bloggin n');
@define('TOP_EXITS', 'Topp tgnguleiir');
@define('SHOWS_TOP_EXIT', 'Snir helstu tgnguleiir fr bloggunum num');
@define('SYNDICATION', 'Sjlfvirkni');
@define('SHOWS_RSS_BLAHBLAH', 'Snir RSS tengla');
@define('ADVERTISES_BLAHBLAH', 'Auglsir uppruna bloggsins');
@define('HTML_NUGGET', 'HTML stubbur');
@define('HOLDS_A_BLAHBLAH', 'Stubbur fyrir HTML  hliarrammann inn');
@define('TITLE_FOR_NUGGET', 'Titill fyrir stubbinn');
@define('THE_NUGGET', 'Stubbur HTML!');
@define('SYNDICATE_THIS_BLOG', 'Skru RSS fyrir etta blogg');
@define('YOU_CHOSE', ' valdir %s');
@define('IMAGE_ROTATE_LEFT', 'Sna mynd 90 grur rangslis');
@define('IMAGE_ROTATE_RIGHT', 'Sna mynd 90 grur rttslis');
@define('IMAGE_SIZE', 'Str myndar');
@define('IMAGE_AS_A_LINK', 'Innsetning myndar');
@define('POWERED_BY', 'Kni af');
@define('TRACKBACKS', 'Tilvsanir');
@define('TRACKBACK', 'Tilvsun');
@define('NO_TRACKBACKS', 'Engar tilvsanir');
@define('TOPICS_OF', 'Fyrirsagnir af');
@define('VIEW_FULL', 'skoa allt');
@define('VIEW_TOPICS', 'skoa fyrirsagnir');
@define('AT', 'sendi klukkan');
@define('SET_AS_TEMPLATE', 'Setja sem forsni');
@define('IN', '');
@define('EXCERPT', 'tdrttur');
@define('TRACKED', 'Raki');
@define('LINK_TO_ENTRY', 'Vsa  frslu');
@define('LINK_TO_REMOTE_ENTRY', 'Vsa  frslu  ru kerfi');
@define('IP_ADDRESS', 'IP tala');
@define('USER', 'Notandi');
@define('THUMBNAIL_USING_OWN', 'Nota %s sem eigi snishorn, ar sem hn er egar svo ltil.');
@define('THUMBNAIL_FAILED_COPY', 'Vildi nota %s sem eigi snishorn, en gat ekki afrita!');
@define('AUTHOR', 'Hfundur');
@define('LAST_UPDATED', 'Sast uppfrt');
@define('TRACKBACK_SPECIFIC', 'URI sl fyrir tilvsun  essa frslu');
@define('DIRECT_LINK', 'Bein sl  essa frslu');
@define('COMMENT_ADDED', 'Athugasemd inni hefur veri btt vi. ');
@define('COMMENT_ADDED_CLICK', 'Smelltu %shr til a fara%s  athugasemdir, og %shr til a loka%s essum glugga.');
@define('COMMENT_NOT_ADDED_CLICK', 'Smelltu %shr til a fara%s  athugasemdir, og %shr til a loka%s essum glugga.');
@define('COMMENTS_DISABLE', 'Leyfa ekki athugasemdir  essa frslu');
@define('COMMENTS_ENABLE', 'Leyfa athugasemdir  essu frslu');
@define('COMMENTS_CLOSED', 'Hfundurinn leyfir ekki athugasemdir  essa frslu');
@define('EMPTY_COMMENT', 'Athugasemdin n innihlt ekki neitt, svo vinsamlegast %sfaru til baka%s og reyndu aftur');
@define('ENTRIES_FOR', 'Frslur fyrir %s');
@define('DOCUMENT_NOT_FOUND', 'Skjali %s fannst ekki.');
@define('USERNAME', 'Notandanafn');
@define('PASSWORD', 'Lykilor');
@define('AUTOMATIC_LOGIN', 'Vista upplsingar');
@define('SERENDIPITY_INSTALLATION', 'Serendipity uppsetning');
@define('LEFT', 'vinstri');
@define('RIGHT', 'hgri');
@define('HIDDEN', 'falinn');
@define('REMOVE_TICKED_PLUGINS', 'Fjarlgja hakaar vibtur');
@define('SAVE_CHANGES_TO_LAYOUT', 'Vista tlitsbreytingar');
@define('COMMENTS_FROM', 'Athugasemdir fr');
@define('ERROR', 'Villa');
@define('ENTRY_SAVED', 'Frslan n hefur veri vistu');
@define('DELETE_SURE', 'Ertu viss um a  viljir eya #%s endanlega?');
@define('NOT_REALLY', 'Nei, eiginlega ekki...');
@define('DUMP_IT', 'Fleygu essu!');
@define('RIP_ENTRY', 'Hvldu  frii, frsla #%s');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Flokki #%s eytt. Frslur frar  flokk #%s');
@define('CATEGORY_DELETED', 'Flokki #%s eytt.');
@define('INVALID_CATEGORY', 'Enginn flokkur var valinn til eyingar');
@define('CATEGORY_SAVED', 'Flokkur vistaur');
@define('SELECT_TEMPLATE', 'Veldu forsnii sem  vilt nota fyrir bloggi itt');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Vibt frsla tkst ekki!');
@define('MT_DATA_FILE', 'Movable Type gagnaskr');
@define('FORCE', 'vinga');
@define('CREATE_AUTHOR', 'Ba til hfund \'%s\'.');
@define('CREATE_CATEGORY', 'Ba til flokk \'%s\'.');
@define('MYSQL_REQUIRED', ' verur a hafa MySQL vibtina til a gera etta.');
@define('COULDNT_CONNECT', 'Gat ekki tengst MySQL gagnagrunni: %s.');
@define('COULDNT_SELECT_DB', 'Gat ekki vali gagnagrunn: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Gat ekki vali notandaupplsingar: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Gat ekki vali flokksupplsingar: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Gat ekki vali frsluupplsingar: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Gat ekki vali athugasemdaupplsingar: %s.');
@define('YES', 'J');
@define('NO', 'Nei');
@define('USE_DEFAULT', 'Sjlfgefi');
@define('CHECK_N_SAVE', 'Prfa &amp; vista');
@define('DIRECTORY_WRITE_ERROR', 'Get ekki skrifa  mppu %s. Athugau eiginleika hennar.');
@define('DIRECTORY_CREATE_ERROR', 'Mappan %s er ekki til og gat ekki bi hana til. Vinsamlegast bu hana til  annan htt');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; keyra <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Get ekki keyrt %s skrna');
@define('FILE_WRITE_ERROR', 'Gat ekki skrifa  skr %s.');
@define('FILE_CREATE_YOURSELF', 'Vinsamlegast bu skrna til sjlfur ea athugau eiginleika');
@define('COPY_CODE_BELOW', '<br />* Vistau bara kann fyrir nean og settu hann  %s  %s mppunni:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Breyttu www  notandann sem a apache keyrir sem (t.d. nobody).');
@define('BROWSER_RELOAD', 'egar  ert binn a v, uppfru  sunna me "reload/refresh" takkanum.');
@define('DIAGNOSTIC_ERROR', 'Vi urum vr vi einhverjar villur egar vi keyrum greiningar  upplsingunum sem  gafst:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity er ekki uppsett. Vinsamlegast <a href="%s">settu a upp</a> nna.');
@define('INCLUDE_ERROR', 'serendipity villa: gat ekki innlima %s - htti.');
@define('DATABASE_ERROR', 'serendipity villa: gat ekki tengst gagnagrunni - htti.');
@define('CREATE_DATABASE', 'Geri sjlfgefnu uppsetninguna  gagnagrunninum...');
@define('ATTEMPT_WRITE_FILE', 'Reyni a skrifa %s skrna...');
@define('WRITTEN_N_SAVED', 'Stillingar skrifaar &amp; vistaar');
@define('IMAGE_ALIGNMENT', 'Stasetning myndar');
@define('ENTER_NEW_NAME', 'Slu inn ntt nafn fyrir: ');
@define('RESIZING', 'Breyti str');
@define('RESIZE_DONE', 'Bin (breytti str %s mynda).');
@define('SYNCING', 'Samhfi gagnagrunn vi myndamppu');
@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
@define('SYNC_DONE', 'Bin (Samhfi %s myndir).');
@define('FILE_NOT_FOUND', 'Fann ekki skrna <b>%s</b>, kannski er egar bi a eya henni?');
@define('ABORT_NOW', 'Htta vi nna');
@define('REMOTE_FILE_NOT_FOUND', 'Skrin fannst ekki  endajninum. Ertu viss um a slin: <b>%s</b> s rtt?');
@define('FILE_FETCHED', '%s stt sem %s');
@define('FILE_UPLOADED', 'Skr %s vistu sem %s');
@define('WORD_OR', 'Ea');
@define('SCALING_IMAGE', 'Breyti str %s  %s x %s px');
@define('KEEP_PROPORTIONS', 'Halda hlutfllum');
@define('REALLY_SCALE_IMAGE', 'Ertu viss a  viljir breyta str myndarinnar? a er ekki hgt a breyta til baka!');
@define('TOGGLE_ALL', 'Virkja stkka allt');
@define('TOGGLE_OPTION', 'Virkja valmguleika');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Gerast skrifandi a essari frslu');
@define('UNSUBSCRIBE_OK', "%s hefur n veri afskrur fr essari frslu");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'N athugasemd  frslu  skrift "%s"');
@define('SUBSCRIPTION_MAIL', "Hall %s,\n\nN athugasemd hefur veri ger  frslu sem  ert a fylgjast me  \"%s\", kllu \"%s\"\nNafn sendanda er: %s\n\n getur fundi frsluna hr: %s\n\n getur htt vi skrift me v a smella  ennan hlekk: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Hall %s,\n\nNrri tilvsun var btt vi frsluna sem  ert a fylgjast me  \"%s\", kllu \"%s\"\nNafn sendanda er: %s\n\n getur fundi frsluna hr: %s\n\n getur htt vi skrift me v a smella  ennan hlekk: %s\n");
@define('SIGNATURE', "\n-- \n%s er kni af Serendipity.\nBesta bloggkerfi sem til er, og  getur nota a lka.\nKktu  <http://s9y.org> til a komast a v hvernig.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 straumur');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 straumur');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 straumur');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 athugasemdir');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 straumur');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Svi "manageEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Svi "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Mynd fyrir RSS strauminn');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Breidd myndar');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'H myndar');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'Netfang vefstjra, ef a er fyrir hendi. (tmt: fali) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'Netfang umsjnaraila, ef a er fyrir hendi. (tmt: fali) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'Sl (URL) myndar  GIF/JPEG/PNG snii, ef fyrir hendi. (tmt: serendipity-logo)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', ' pixelum, hmark 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', ' pixelum, hmark 400');
@define('SYNDICATION_PLUGIN_TTL', 'Svi "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'S tmi sem bloggi tti ekki lengur a vera vista af rum framandi sum/forritum (tmt: fali) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Svi "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'tti "pubDate"-svi a vera innbyggt fyrir RSS-rs, til a sna dagsetningu sustu frslu?');
@define('CONTENT', 'Innihald');
@define('TYPE', 'Tegund');
@define('DRAFT', 'Drg');
@define('PUBLISH', 'Birta');
@define('PREVIEW', 'Skoa');
@define('DATE', 'Dagsetning');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Var: Dagsetningin sem  skilgreindir var lgleg. Hn verur a vera gefin  -MM-DD KK:MM snii.');
@define('CATEGORY_PLUGIN_DESC', 'Snir listann af flokkum.');
@define('ALL_AUTHORS', 'Allir hfundar');
@define('CATEGORIES_TO_FETCH', 'Flokkar til a skja');
@define('CATEGORIES_TO_FETCH_DESC', 'Skja flokka fr hvaa hfundi?');
@define('PAGE_BROWSE_ENTRIES', 'Blasa %s af %s, me samtals %s frslur');
@define('PREVIOUS_PAGE', 'fyrri sa');
@define('NEXT_PAGE', 'nsta sa');
@define('ALL_CATEGORIES', 'Allir flokkar');
@define('DO_MARKUP', 'Gera breytingar  texta');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Dagsetningarsni');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Sni alvru dagsetningar frslunnar, sem notar strftime() breytu PHP. (Sjlfgefi: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Gat ekki opna forsnisskr, vinsamlegast uppfru Serendipity!');
@define('ADVANCED_OPTIONS', 'rair mguleikar');
@define('EDIT_ENTRY', 'Breyta frslu');
@define('HTACCESS_ERROR', 'Til a athuga uppsetninguna  stabundna vefjninum arf serendipity a geta skrifa  skrna ".htaccess". etta var ekki hgt vegna leyfisstillinga. Vinsamlegast breyttu leyfum skrarinnar svona:  <br />&nbsp;&nbsp;%s<br />og endurhladdu essari su.');
@define('SIDEBAR_PLUGINS', 'Vibtur hliarramma');
@define('EVENT_PLUGINS', 'Vibtur atbura');
@define('SORT_ORDER', 'Runarregla');
@define('SORT_ORDER_NAME', 'Skrarnafn');
@define('SORT_ORDER_EXTENSION', 'Skrarending');
@define('SORT_ORDER_SIZE', 'Skrarstr');
@define('SORT_ORDER_WIDTH', 'Breidd myndar');
@define('SORT_ORDER_HEIGHT', 'H myndar');
@define('SORT_ORDER_DATE', 'Dagsetning vistunar');
@define('SORT_ORDER_ASC', 'Upp  vi');
@define('SORT_ORDER_DESC', 'Niur  vi');
@define('THUMBNAIL_SHORT', 'Snishorni');
@define('ORIGINAL_SHORT', 'Upphafl.');
@define('APPLY_MARKUP_TO', 'Virkja textabreytingar  %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Upphaf vikunnar');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity hefur teki eftir a stillingarnar nar eru uppsettar fyrir tgfu %s, en nverandi tgfa er %s.  arft v a uppfra! <a href="%s">Smelltu hr</a>'); 
@define('SERENDIPITY_UPGRADER_WELCOME', 'Gan dag, og velkomin  uppfrsluforrit Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'g er hr til a hjlpa r a uppfra Serendipity %s uppsetninguna na.');
@define('SERENDIPITY_UPGRADER_WHY', ' sr essi skilabo vegna ess a  hefur sett upp Serendipity %s, en  hefur ekki uppfrt gagnagrunnsuppsetninguna til a passa vi essa tgfu');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Uppfrslur gagnagrunns (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'g fann eftirfarandi .sql skrr sem arf a keyra ur en  getur haldi fram me venjulega keyrslu  Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Agerir bundar vi essa tgfu');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Engar agerir bundar vi essa tgfu fundust');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Viltu a g framkvmi ofangreindar agerir?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Nei, g mun gera r handvirkt');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'J takk, geru a');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'a virist sem svo a  urfir ekki a keyra neinar uppfrslur');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Uppfrslu loki');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', ' hefur hundsa uppfrslustig Serendipity. Vinsamlegast gakktu r skugga um a gagnagrunnurinn s rtt uppsettur, og fyrirtlu virkni s  gangi');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Serendipity uppsetningin n hefur n veri uppfr  tgfu %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', ' getur fari aftur  bloggi itt me v a smella %shr%s');
@define('MANAGE_USERS', 'Ssla me notendur');
@define('CREATE_NEW_USER', 'Ba til njan notanda');
@define('CREATE_NOT_AUTHORIZED', ' getur ekki breytt notendum  me sama stjrnstig og ');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', ' getur ekki bi til notendur me hrra stjrnstig en ');
@define('CREATED_USER', 'Nr notandi %s hefur veri binn til');
@define('MODIFIED_USER', 'Eiginleikum notanda %s hefur veri breytt');
@define('USER_LEVEL', 'Stjrnstig');
@define('DELETE_USER', ' ert a fara a eya notanda #%d %s. Ertu viss?  verur ekki hgt a sna frslur eftir hann  sunni.');
@define('DELETED_USER', 'Notanda #%d %s eytt.');
@define('LIMIT_TO_NUMBER', 'Hversu margar frslur skal sna?');
@define('ENTRIES_PER_PAGE', 'frslur  su');
@define('XML_IMAGE_TO_DISPLAY', 'XML takki');
@define('XML_IMAGE_TO_DISPLAY_DESC','Hlekkir  XML strauma vera snd me essari mynd. Skildu eftir tmt fyrir sjlfgefi gildi, ea slu inn \'none\' til a virkja.');

@define('DIRECTORIES_AVAILABLE', ' listanum af mgulegum undirmppum geturu smellt  hvaa mppu sem er til a ba til nja mppu innan hennar.');
@define('ALL_DIRECTORIES', 'allar mppur');
@define('MANAGE_DIRECTORIES', 'Ssla me mppur');
@define('DIRECTORY_CREATED', 'Mappan <strong>%s</strong> hefur veri bin til.');
@define('PARENT_DIRECTORY', 'Yfirmappa');
@define('CONFIRM_DELETE_DIRECTORY', 'Ertu viss um a  viljir fjarlgja allt innihald mppunnar %s?');
@define('ERROR_NO_DIRECTORY', 'Villa: Mappan %s er ekki til');
@define('CHECKING_DIRECTORY', 'Athuga skrr  mppu %s');
@define('DELETING_FILE', 'Eyi skr %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Gat ekki fjarlgt mppuna sem var ekki tm. Athugau "vinga eyslu" haki ef  vilt fjarlgja essar skrr lka, og reyndi svo aftur. Skrr sem enn eru til:');
@define('DIRECTORY_DELETE_FAILED', 'Eysla mppu %s gekk ekki. Athugau rttindi ea skilabo a ofan.');
@define('DIRECTORY_DELETE_SUCCESS', 'Mappa Directory %s successfully deleted.');
@define('SKIPPING_FILE_EXTENSION', 'Sleppi skr: Vantar ending  %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Sleppi skr: %s ekki lsileg.');
@define('FOUND_FILE', 'Fann nja/breytta skr: %s.');
@define('ALREADY_SUBCATEGORY', '%s er egar undirmappa %s.');
@define('PARENT_CATEGORY', 'Yfirflokkur');
@define('IN_REPLY_TO', 'Sem svar vi');
@define('TOP_LEVEL', 'Toppstigi');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s straumur');
@define('PERMISSIONS', 'Rttindi');
@define('INTEGRITY', 'Verify Installation Integrity');
@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
@define('CHECKSUMS_PASS', 'All required files verified.');
@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
@define('SETTINGS_SAVED_AT', 'Nju stillingarnar voru vistaar klukkan %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Stillingar gagnagrunns');
@define('INSTALL_CAT_DB_DESC', 'Hr getur  slegi inn allar upplsingar um gagnagrunninn. Serendipity arf etta til a geta virka');
@define('INSTALL_DBTYPE', 'Tegund gagnagrunns');
@define('INSTALL_DBTYPE_DESC', 'Tegund gagnagrunns');
@define('INSTALL_DBHOST', 'Vlarnafn (host) gagnagrunns');
@define('INSTALL_DBHOST_DESC', 'Vlarnafni  gagnagrunninum num');
@define('INSTALL_DBUSER', 'Notandi gagnagrunns');
@define('INSTALL_DBUSER_DESC', 'Notandanafni sem nota verur til a tengjast gagnagrunninum');
@define('INSTALL_DBPASS', 'Lykilor gagnagrunns');
@define('INSTALL_DBPASS_DESC', 'Lykilori sem nota  me notandanafninu a ofan');
@define('INSTALL_DBNAME', 'Nafn gagnagrunns');
@define('INSTALL_DBNAME_DESC', 'Nafni  gagnagrunninum num');
@define('INSTALL_DBPREFIX', 'Fasti  undan frslum  gagnagrunni');
@define('INSTALL_DBPREFIX_DESC', 'Fasti fyrir nfn  tflum, t.d. serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Slir');
@define('INSTALL_CAT_PATHS_DESC', 'Nokkrar slir  mikilvgar mppur og skrr. Ekki gleyma skstrikinu  eftir mppunfnum (mappa/)!');
@define('INSTALL_FULLPATH', 'Full sl');
@define('INSTALL_FULLPATH_DESC', 'Full og algjr sl  serendipity uppsetninguna na');
@define('INSTALL_UPLOADPATH', 'Vistunarsl');
@define('INSTALL_UPLOADPATH_DESC', 'All sem er vista mun fara hinga, m.t.t. fulla sl - vanalega \'uploads\'');
@define('INSTALL_RELPATH', 'Hlutfallsleg sl');
@define('INSTALL_RELPATH_DESC', 'Slin  serendipity fyrir vafrann inn, vanalega \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Hlutfallsleg sl  forsni');
@define('INSTALL_RELTEMPLPATH_DESC', 'Slin  mppuna sem inniheldur forsniin n - m.t.t. til \'hlutfallslega sl\'');
@define('INSTALL_RELUPLOADPATH', 'Hlutfallsleg vistunarsl');
@define('INSTALL_RELUPLOADPATH_DESC', 'Slin  vistaar skrr fyrir vafra - m.t.t. \'hlutfallslegar slar\'');
@define('INSTALL_URL', 'Sl (URL)  bloggi itt');
@define('INSTALL_URL_DESC', 'Grunnslin (Base URL)  serendipity uppsetninguna na');
@define('INSTALL_INDEXFILE', 'Index skr');
@define('INSTALL_INDEXFILE_DESC', 'Nafni  serendipity index skrnni inni');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', 'Almennar stillingar');
@define('INSTALL_CAT_SETTINGS_DESC', 'Veldu hvernig Serendipity hagar sr');
@define('INSTALL_USERNAME', 'Notandanafn umsjnarmanns');
@define('INSTALL_USERNAME_DESC', 'Notandanafn fyrir innskrningu umsjnarmanns');
@define('INSTALL_PASSWORD', 'Lykilor umsjnarmanns');
@define('INSTALL_PASSWORD_DESC', 'Lykilor fyrir innskrningu umsjnarmanns');
@define('INSTALL_EMAIL', 'Netfang umsjnarmanns');
@define('INSTALL_EMAIL_DESC', 'Netfang umsjnarmanns bloggsins');
@define('INSTALL_SENDMAIL', 'Senda pst  umsjnarmann?');
@define('INSTALL_SENDMAIL_DESC', 'Viltu f sendan pst egar athugasemdir eru sendar  frslurnar nar?');
@define('INSTALL_SUBSCRIBE', 'Leyfa notendum a gerast skrifendur a frslum?');
@define('INSTALL_SUBSCRIBE_DESC', 'Leyfir notendum a gerast skrifendur a frslu, og f ar me pst egar njar athugasemdir eru gerar   frslu');
@define('INSTALL_BLOGNAME', 'Nafn bloggs');
@define('INSTALL_BLOGNAME_DESC', 'Fyrirsgnin  blogginu nu');
@define('INSTALL_BLOGDESC', 'Lsing bloggs');
@define('INSTALL_BLOGDESC_DESC', 'Lsing  blogginu nu');
@define('INSTALL_LANG', 'Tunguml');
@define('INSTALL_LANG_DESC', 'Veldu tungumli sem vera skal  blogginu nu');

/* APPEARANCE AND OPTIONS */
@define('INSTALL_CAT_DISPLAY', 'tlit og valmguleikar');
@define('INSTALL_CAT_DISPLAY_DESC', 'Stilltu tilfinningu og tlit Serendipity t  vi');
@define('INSTALL_WYSIWYG', 'Nota WYSIWYG ritilinn');
@define('INSTALL_WYSIWYG_DESC', 'Viltu nota WYSIWYG ritilinn? (Virkar  IE5+, og a hluta til  Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Neya XHTML 1.1 fylgni');
@define('INSTALL_XHTML11_DESC', 'Viltu neya XHTML 1.1 fylgni (getur valdi vandrum fyrir bak- ea framvinnslu fyrir eldri fjrukynslar vafra)');
@define('INSTALL_POPUP', 'Virkja notkun innskotsglugga');
@define('INSTALL_POPUP_DESC', 'Viltu nota innskotsglugga (popup) fyrir athugasemdir, tilvsanir, o.fl.?');
@define('INSTALL_EMBED', 'Er Serendipity innifali?');
@define('INSTALL_EMBED_DESC', 'Ef  vilt innifela serendipity  annarri su, stilltu   "true" a henda llum hausum, og prenta bara innihaldi.  getur ntt indexFile valmguleikann til a nota "wrapper class" ar sem  setur venjulega vefsuhausa. Sj README skr fyrir meiri upplsingar.');
@define('INSTALL_TOP_AS_LINKS', 'Sna topp tgnguleiir/vsara sem tengla?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"nei": tgnguleiir og vsarar eru snd sem venjulegur texti til a verjast google rusli. "j": tgnguleiir og vsarar eru sndir sem tenglar. "sjlfgefi": Nota stillingu r almennum stillingum (rlagt).');
@define('INSTALL_BLOCKREF', 'leyfir vsarar');
@define('INSTALL_BLOCKREF_DESC', 'Eru einhverjar srstakar vlar sem  vilt ekki lta sjst  vsaralistanum? Askildu lista vlanafna me \';\' og hafu  huga a vlarnafninu er sleppt me "substring matches"!');
@define('INSTALL_REWRITE', 'Endurskrifun sla (URL)');
@define('INSTALL_REWRITE_DESC', 'Veldu hvaa reglur  vilt nota til a endurskrifa slir (URL). A hafa etta virkt mun gera slir  bloggi itt fallegar og einfaldar, og gera auveldara fyrir vefkngulr (s.s. google) a gera efnisyfirlit  suna). Vefjnninn arf a styja annahvort mod_rewrite ea "AllowOverride All" fyrir serendipity mppuna na. Sjjlfgefna stillingin er a skynja a sjlfkrafa.');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', 'Myndbreytingastillingar:');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Skru inn almennar upplsingar um hvernig serendipity tti a sj um myndir');
@define('INSTALL_IMAGEMAGICK', 'Nota Imagemagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Ertu me imagemagick uppsett og vilt nota a til a breyta str mynda?');
@define('INSTALL_IMAGEMAGICKPATH', 'Sl  forriti');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Full sl og nafni  imagemagick myndvinnsuforritinu');
@define('INSTALL_THUMBSUFFIX', 'Viskeyti snishorna');
@define('INSTALL_THUMBSUFFIX_DESC', 'Snishorn vera nefnd eftir eftirfarandi forsnii: upprunalegt.[viskeyti].end');
@define('INSTALL_THUMBWIDTH', 'Str snishorna');
@define('INSTALL_THUMBWIDTH_DESC', 'Stala hgildi breiddar framkallara snishorna');
@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
@define('INSTALL_THUMBDIM_WIDTH', 'Width');
@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
    '" only limit the chosen dimension, so the other could be larger than the max size.');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Persnulegu upplsingar nar');
@define('USERCONF_CAT_PERSONAL_DESC', 'Breyta persnulegu upplsingum num');
@define('USERCONF_USERNAME', 'Notandanafn itt');
@define('USERCONF_USERNAME_DESC', 'Notandanafni sem  notar til a skr ig inn  bloggi');
@define('USERCONF_PASSWORD', 'Lykilori itt');
@define('USERCONF_PASSWORD_DESC', 'Lykilori sem  notar til a skr igg inn  bloggi');
@define('USERCONF_EMAIL', 'Netfangi itt');
@define('USERCONF_EMAIL_DESC', 'Persnulega netfangi itt');
@define('USERCONF_SENDCOMMENTS', 'Senda tilkynningar v/athugasemda?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Viltu f sendan pst egar athugasemdir eru sendar  frslurnar nar?');
@define('USERCONF_SENDTRACKBACKS', 'Senda tilkynningar v/tilvsana?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Viltu f sendan pst egar tilvsanir eru gerar  frslurnar nar?');
@define('USERCONF_ALLOWPUBLISH', 'Rttindi: Birta frslur?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'M essi notandi birta frslur?');
@define('SUCCESS', 'rangur');
@define('POWERED_BY_SHOW_TEXT', 'Sna "Serendipity" sem texa');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Mun birta "Serendipity Weblog" sem texta');
@define('POWERED_BY_SHOW_IMAGE', 'Sna "Serendipity" me merki');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Snir merki Serendipity');
@define('PLUGIN_ITEM_DISPLAY', 'Hvar tti merki a vera snt?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Opna bara frslu');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Yfirsn yfir bara blasu');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'llum stundum');
@define('RSS_IMPORT_CATEGORY', 'Nota ennan flokk fyrir frslur sem passa ekki  neinn flokk');

@define('COMMENTS_WILL_BE_MODERATED', 'Innsendar athugasemdir urfa a f samykki ur en r vera birtar.');
@define('YOU_HAVE_THESE_OPTIONS', ' hefur eftirfarandi valmguleika fyrir hendi:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Athuga: essi athugasemd arf samykki ur en hn verur birt');
@define('DELETE_COMMENT', 'Eya athugasemd');
@define('APPROVE_COMMENT', 'Samykkja athugasemd');
@define('REQUIRES_REVIEW', 'arf yfirlesningu');
@define('COMMENT_APPROVED', 'Athugasemd #%s hefur veri samykkt');
@define('COMMENT_DELETED', 'Athugasemd #%s hefur veri eytt');
@define('COMMENTS_MODERATE', 'Athugasemdir & tilvsanir  essa frslu urfa samykki');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Athuga: essi tilvsun arf samykki ur en hn verur birt');
@define('DELETE_TRACKBACK', 'Eya tilvsun');
@define('APPROVE_TRACKBACK', 'Samykkja tilvsun');
@define('TRACKBACK_APPROVED', 'Tilvsun #%s hefur veri samykkt');
@define('TRACKBACK_DELETED', 'Tilvsun #%s hefur veri eytt');
@define('VIEW', 'Skoa');
@define('COMMENT_ALREADY_APPROVED', 'Athugasemd #%s virist egar hafa veri samykkt');
@define('COMMENT_EDITED', 'Athugasemdinni hefur veri breytt');
@define('HIDE', 'Fela');
@define('VIEW_EXTENDED_ENTRY', 'Halda fram a lesa "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'a er ekki tlast til ess a smellt s  ennan hlekk. Hann inniheldur tilvsunar URIs lina fyrir essa frslu.  getur nota etta URI til a senda ping- & tilvsanir fr eigin bloggi  essa frslu. Til a afrita ennan hlekk, hgrismelltu   hlekkinn og veldu "Copy Shortcut"  Internet Explorer, og "Copy Link Location"  Mozilla.');
@define('PLUGIN_SUPERUSER_HTTPS', 'Nota https fyrir innskrningu');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Ltur innskrningarhlekkinn vsa  https sl. Vefjnninn inn arf a styja etta!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Lta vera hgt a smellta  utanakomandi hlekki?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"nei": skoair hlekkir t  vi (Topp tgnguleiir, vsarar, athugasemdir notenda) eru sndar/ekki sndar sem venjulegur texti egar  vi til a koma  veg fyrir google ruslsendingar (rlagt). "j": skoair hlekkir t  vi eru sndir sem hlekkir. Getur veri breytt me ra valdi innan hliarramma stillingum!');
@define('PAGE_BROWSE_COMMENTS', 'Blasa %s af %s, me %s athugasemdir');
@define('FILTERS', 'Sur');
@define('FIND_ENTRIES', 'Finna frslur');
@define('FIND_COMMENTS', 'Finna athugasemdir');
@define('FIND_MEDIA', 'Finna ggn');
@define('FILTER_DIRECTORY', 'Mppum');
@define('SORT_BY', 'Raa eftir');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Engin tilvsun send: Ni ekki sambandi vi %s  porti %d');
@define('MEDIA', 'Ggn');
@define('MEDIA_LIBRARY', 'Gagnasafn');
@define('ADD_MEDIA', 'Bta vi ggnum');
@define('ENTER_MEDIA_URL', 'Slu inn sl skrarinnar til a skja:');
@define('ENTER_MEDIA_UPLOAD', 'Veldu skrna sem  vilt vista:');
@define('SAVE_FILE_AS', 'Vista skr sem:');
@define('STORE_IN_DIRECTORY', 'Vista innan eftirfarandi mppu: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>Bta vi skr  gagnageymsluna na:</b><p>Hr geturu vista gagnaskrr, ea sagt mr a skja r einhversstaar annarsstaar fr af vefnum! Ef  ert ekki me mynd vi hfi, <a href="http://images.google.com" target="_blank">leitau a myndum  google</a> sem  vi a sem  ert a hugsa. Niursturnar eru oft nytsamlegar og fyndnar :)</p><p><b>Veldu lei:</b></p><br/>');
@define('MEDIA_RENAME', 'Endurnefna skrna');
@define('IMAGE_RESIZE', 'Breyta str myndarinnar');
@define('MEDIA_DELETE', 'Eya essari skr');
@define('FILES_PER_PAGE', 'Skrr  su');
@define('CLICK_FILE_TO_INSERT', 'Smelltu  skrna sem  vilt bta vi:');
@define('SELECT_FILE', 'Veldu skrna til a bta vi');
@define('MEDIA_FULLSIZE', 'Fylla skjinn');
@define('CALENDAR_BOW_DESC', 'Dagur vikunnar sem er tekinn sem byrjunardagur vikunnar. Sjlfgefi gildi er mnudagur');
@define('SUPERUSER', 'Umsjn vefkerfis');
@define('ALLOWS_YOU_BLAHBLAH', 'Gerir hlekk  hliarramma bloggkerfisins sem vsar  umsjnarkerfi');
@define('CALENDAR', 'Dagatal');
@define('SUPERUSER_OPEN_ADMIN', 'Opna umsjnarkerfi');
@define('SUPERUSER_OPEN_LOGIN', 'Opna innskrningarsu');
@define('INVERT_SELECTIONS', 'Skipta t vldu fyrir vali');
@define('COMMENTS_DELETE_CONFIRM', 'Ertu viss um a  viljir eya vldum athugasemdum?');
@define('COMMENT_DELETE_CONFIRM', 'Ertu viss um a  viljir eya athugasemd #%d, skrifari af %s?');
@define('DELETE_SELECTED_COMMENTS', 'Eya vldum athugasemdum');
@define('VIEW_COMMENT', 'Skoa athugasemd');
@define('VIEW_ENTRY', 'Skoa frslu');
@define('DELETE_FILE_FAIL' , 'Gat ekki eytt skr <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Eyddi snishorni myndar nefnt <b>%s</b>');
@define('DELETE_FILE', 'Eyddi skr nenfdri <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', ' ert a far aa eya <b>%s</b><br />Ef  ert a nota essa skr  einhverri af frslunum num, mun a valda dauum hlekkjum ea virkum myndum<br />Ertu viss um a  viljir halda fram?<br /><br />');
@define('TRACKBACK_SENDING', 'Sendi tilvsun  URI sl %s...');
@define('TRACKBACK_SENT', 'Tilvsun tkst');
@define('TRACKBACK_FAILED', 'Tilvsun tkst ekki: %s');
@define('TRACKBACK_NOT_FOUND', 'Engin URI-tilvsunarsl fannst.');
@define('TRACKBACK_URI_MISMATCH', 'URI slin sem g fann t passar ekki vi URI slina sem vi tluum a nota.');
@define('TRACKBACK_CHECKING', 'Athuga <u>%s</u> fyrir mgulegar tilvsanir...');
@define('TRACKBACK_NO_DATA', 'Vifang innihlt engin ggn');
@define('TRACKBACK_SIZE', 'VifangsURI-sl fr fram r leyfri str, %s btum.');
@define('COMMENTS_VIEWMODE_THREADED', 'rddan ham');
@define('COMMENTS_VIEWMODE_LINEAR', 'Flatan ham');
@define('DISPLAY_COMMENTS_AS', 'Sna athugasemdir sem');
@define('COMMENTS_FILTER_SHOW', 'Sna');
@define('COMMENTS_FILTER_ALL', 'Allt');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Einungis samykktar');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Ba eftir samykki');
@define('RSS_IMPORT_BODYONLY', 'Setja allan innfluttan texta  "body" hlutann og ekki skipta  "aukainnihald" hlutann.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Show full articles with extended body inside RSS feed');
@define('WEEK', 'Vika');
@define('WEEKS', 'Vikur');
@define('MONTHS', 'Mnuir');
@define('DAYS', 'Dagar');
@define('ARCHIVE_FREQUENCY', 'Tni hlutar  dagatali');
@define('ARCHIVE_FREQUENCY_DESC', 'Bili  milli sem nota   dagatali  milli tveggja hluta  listanum');
@define('ARCHIVE_COUNT', 'Fjldi hluta  listanum');
@define('ARCHIVE_COUNT_DESC', 'Heildarfjldi mnaa, vika ea daga til a birta');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'A nean er listi uppsettra vibta');
@define('SIDEBAR_PLUGIN', 'hliarrammavibt');
@define('EVENT_PLUGIN', 'atburavibt');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Smelltu hr til a setja inn nja %s');
@define('VERSION', 'tgfa');
@define('INSTALL', 'Setja upp');
@define('ALREADY_INSTALLED', 'egar uppsett');
@define('SELECT_A_PLUGIN_TO_ADD', 'Veldu vibt til a setja inn');
@define('INSTALL_OFFSET', 'Frvik fr jnstma');
@define('STICKY_POSTINGS', 'rautseigar innsetningar');
@define('INSTALL_FETCHLIMIT', 'Frslur sem sna skal  forsu');
@define('INSTALL_FETCHLIMIT_DESC', 'Fjldi frsla sem sna skal  hverri su');
@define('IMPORT_ENTRIES', 'Flytja inn ggn');
@define('EXPORT_ENTRIES', 'Flytja t ggn');
@define('IMPORT_WELCOME', 'Velkomin(n)  innflutningstl Serendipity');
@define('IMPORT_WHAT_CAN', 'Hr getur  flutt inn frslur fr rum bloggkerfum');
@define('IMPORT_SELECT', 'Veldu hugbnainn sem  vilt flytja inn fr');
@define('IMPORT_PLEASE_ENTER', 'Vinsamlegast slu inn ggnin eins og er fari fram  a nean');
@define('IMPORT_NOW', 'Flytja inn nna!');
@define('IMPORT_STARTING', 'Hef innflutningsferli...');
@define('IMPORT_FAILED', 'Innflutningur mistkst');
@define('IMPORT_DONE', 'Innflutningi loki');
@define('IMPORT_WEBLOG_APP', 'Bloggkerfi');
@define('IMPORT_NOTES', 'Athuga:');
@define('EXPORT_FEED', 'Flytja t allan RSS straum');
@define('STATUS', 'Staa eftir innflutning');
@define('IMPORT_GENERIC_RSS', 'Almennur RSS innflutningur');
@define('ACTIVATE_AUTODISCOVERY', 'Senda tilvsanir  hlekki sem fyrirfinnast  frslunni');
@define('WELCOME_TO_ADMIN', 'Velkomin(n)  stjrnbor Serendipity.');
@define('PLEASE_ENTER_CREDENTIALS', 'Vinsamlegast aukenndu ig.');
@define('ADMIN_FOOTER_POWERED_BY', 'Kni af Serendipity %s og PHP %s');
@define('INSTALL_USEGZIP', 'Nota gzip til a jappa sum');
@define('INSTALL_USEGZIP_DESC', 'Til a flta afhendingu sa getum vi jappa ggnunum og sent gestunum, ef vafrinn hans styur a. Vi mlum me essu');
@define('INSTALL_SHOWFUTURE', 'Sna framtarfrslur');
@define('INSTALL_SHOWFUTURE_DESC', 'Ef virkt, mun etta sna allar frslur sem  sendir inn  framtinni  bloggi. Sjlfgefi er a fela r ar til a birtingardagsetningin er komin.');
@define('INSTALL_DBPERSISTENT', 'Vihalda tengingum?');
@define('INSTALL_DBPERSISTENT_DESC', 'Virkja notkun langlfra tenginga  gagnagrunn, lesa meira <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">hr</a>. A jafnai mlum vi ekki me essu');
@define('NO_IMAGES_FOUND', 'Engar myndir fundust');
@define('PERSONAL_SETTINGS', 'Persnulegar stillingar');
@define('REFERER', 'vsari');
@define('NOT_FOUND', 'Fannst ekki');
@define('WRITABLE', 'Skrifanlegt');
@define('NOT_WRITABLE', 'Ekki skrifanlegt');
@define('PROBLEM_DIAGNOSTIC', 'Vegna vandkva  greiningu geturu ekki haldi fram fyrr en ofangreindar villur eru lagfrar');
@define('SELECT_INSTALLATION_TYPE', 'Veldu hvaa tegund uppsetningar  vilt nota');
@define('WELCOME_TO_INSTALLATION', 'Velkomin(n)  uppsetningu Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', 'Fyrst munum vi lta  nverandi uppsetningu og finna t r hvort einhver samhfingarvandaml su til staar');
@define('ERRORS_ARE_DISPLAYED_IN', 'Villur eru birtar  %s, memli  %s og rangur  %s');
@define('RED', 'rauu');
@define('YELLOW', 'gulu');
@define('GREEN', 'grnu');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s for-uppsetningarskrsla');
@define('RECOMMENDED', 'Mlt me');
@define('ACTUAL', 'Raungildi');
@define('PHPINI_CONFIGURATION', 'php.ini stillingar');
@define('PHP_INSTALLATION', 'PHP uppsetning');
@define('THEY_DO', 'eir/au gera a');
@define('THEY_DONT', 'hann er a ekki');
@define('SIMPLE_INSTALLATION', 'Einfld uppsetning');
@define('EXPERT_INSTALLATION', 'Flkin uppsetning');
@define('COMPLETE_INSTALLATION', 'Ljka uppsetningu');
@define('WONT_INSTALL_DB_AGAIN', 'mun ekki setja upp gagnagrunnin aftur');
@define('CHECK_DATABASE_EXISTS', 'Er a athuga hvort gagnagrunnur s egar til.  Ef  sr villu  uppflettingu  gagnagrunni, hundsau hana...');
@define('CREATING_PRIMARY_AUTHOR', 'B til aalhfund \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Set upp sjlfgefi forsni');
@define('INSTALLING_DEFAULT_PLUGINS', 'Set upp sjlfgefnar vibtur');
@define('SERENDIPITY_INSTALLED', 'Uppsetning Serendipity tkst');
@define('VISIT_BLOG_HERE', 'Heimsktu nja bloggi itt hr');
@define('THANK_YOU_FOR_CHOOSING', 'Takk fyrir a velja Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Villa fannst  uppsetningunni');
@define('OPERATING_SYSTEM', 'Strikerfi');
@define('WEBSERVER_SAPI', 'SAPI vefjns');
@define('TEMPLATE_SET', '\'%s\' hefur veri sett sem virka forsnii itt');
@define('SEARCH_ERROR', 'Leitarftusinn virkai ekki eins og vi mtti bast. Tilkynning sem berast skal umsjnarmanni bloggsins etta getur gerst vegna index lykla  gagnagrunninum sem vantar.  MySQL kerfum verur gagnagrunnsnotandinn a geta gert eftirfarandi eftirspurn: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Nkvm villa sem gagnagrunnurinn skilai var: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'Breyti "%s"');
@define('CATEGORY_REMAINING', 'Eya essum flokki og fra frslur hans  ennan flokk: %s');
@define('CATEGORY_INDEX', 'Fyrir nean er listi af flokkum sem  getur nota  frslurnar nar');
@define('NO_CATEGORIES', 'Engir flokkar');
@define('RESET_DATE', 'Endurstilla dagsetningu');
@define('RESET_DATE_DESC', 'Smelltu hr til a endurstilla dagsetningu  nverandi tma');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Rttindi er hgt a stilla me v a keyra skeljarskipunina `<em>%s</em>`  mppuna ar sem etta mistkst, ea me v a breyta essu  FTP forriti');
@define('WARNING_TEMPLATE_DEPRECATED', 'Var: Forsnii sem  ert me vali er a nota reldar forsnisaferir.  ttir a uppfra ef  hefur tk  v');
@define('ENTRY_PUBLISHED_FUTURE', 'essi frsla hefur ekki enn veri birt.');
@define('ENTRIES_BY', 'Frslur eftir %s');
@define('PREVIOUS', 'Fyrri');
@define('NEXT', 'Nsta');
@define('APPROVE', 'Samykkja');
@define('DO_MARKUP_DESCRIPTION', 'Virkja breytinga r texta t fr kvenum tknum (broskarlar, styttri leiir  gegnum *, /, _, ...). virking  essu mun varveita allan HTML-ka  textanum. Sjlfgefi gildi er "J".');
@define('CATEGORY_ALREADY_EXIST', 'Flokkur me nafninu "s" er egar til');
@define('ERROR_FILE_FORBIDDEN', ' mtt ekki vista skrr me virkt innihald');
@define('ADMIN', 'Stjrn:');
@define('ADMIN_FRONTPAGE', 'Forsa');
@define('QUOTE', 'Tilvitnun');
@define('IFRAME_SAVE', 'Serendipity er n a vista frsluna na, ba til tilvsanir og gera mgulegar XML-RPC agerir. etta gti teki sm stund...');
@define('IFRAME_SAVE_DRAFT', 'Drg a frslu hafa veri vistu');
@define('IFRAME_PREVIEW', 'Serendipity br n til snishorn af frslunni inni...');
@define('IFRAME_WARNING', 'Vafrinn inn skilur ekki iframes hugtaki. Vinsamlegast opnai serendipity_config.inc.php skrna na og stilltu $serendipity[\'use_iframe\'] breytinu  FALSE.');
@define('NONE', 'engin(n)');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Sjlfgefnar stillingar fyrir njar frslur');
@define('UPGRADE', 'Uppfra');
@define('UPGRADE_TO_VERSION', 'Uppfra  tgfu %s');
@define('DELETE_DIRECTORY', 'Eya essari mppu');
@define('DELETE_DIRECTORY_DESC', ' ert a fara a eya innihaldi mppu sem er me margmilunarggn, sem eru mgulega  notkun  sumum frsla inna.');
@define('FORCE_DELETE', 'Neya eyslu skra sem eru ekki inni  milunargagnagrunninum');
@define('CREATE_DIRECTORY', 'Ba til mppu');
@define('CREATE_NEW_DIRECTORY', 'Ba til nja mppu');
@define('CREATE_DIRECTORY_DESC', 'Hr geturu bi til nja mppu til a setja ggn. Veldu nafn  nju mppuna na og veldu mppu til a setja hana  ef vi .');
@define('BASE_DIRECTORY', 'Grunnmappa');
@define('USERLEVEL_EDITOR_DESC', 'Venjulegur notandi');
@define('USERLEVEL_CHIEF_DESC', 'Stjrnandi');
@define('USERLEVEL_ADMIN_DESC', 'Umsjnarmaur');
@define('USERCONF_USERLEVEL', 'Rttindastig');
@define('USERCONF_USERLEVEL_DESC', 'Rttindastig. tti a vera eitt af eftirfarandi: [USERLEVEL_ADMIN] - Umsjnarmaur, [USERLEVEL_CHIEF] - Stjrnandi, [USERLEVEL_EDITOR] - Venjulegur notandi.');
@define('USER_SELF_INFO', 'skr(ur) inn sem %s, me stjrnstig %s');
@define('ADMIN_ENTRIES', 'Frslur');
@define('RECHECK_INSTALLATION', 'Skoa uppsetningu aftur');
@define('IMAGICK_EXEC_ERROR', 'Gat ekki framkvmt: "%s", villa: %s, return var: %d');
@define('INSTALL_OFFSET_DESC', 'Slu inn fjlda klukkustunda sem er  milli vefjnsins ns og tmasvisins sem  vilt hafa (nverandi: %clock%)');
@define('UNMET_REQUIREMENTS', 'uppfylltar arfir: %s');
@define('CHARSET', 'Stafasett (charset)');
@define('AUTOLANG', 'Nota tungumlastillingar vafra gestsins sem sjlfgefi tunguml');
@define('AUTOLANG_DESC', 'Ef etta er virkt mun serendipity nota tungumli sem stillt er   vafra vikomandi gests fyrir vimti (og frslur ef vi ).');
@define('INSTALL_AUTODETECT_URL', 'Skynja sjlfvirkt HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', 'Ef etta er stillt  "true" mun Serendipity sj til ess a HTTP Host nafni sem var nota s nota sem BaseURL stilling. A virkja etta mun gera r kleift a nota mrg mismunandi vlarnfn fyrir Serendipity bloggi itt, og nota a vlarnafn fyrir alla tengla fyrir alla tengla eftir a sem eru notair til a vafra um bloggi itt.');
@define('CONVERT_HTMLENTITIES', 'Reyna a Try to breyta HTML frslum sjlfkrafa?');
@define('EMPTY_SETTING', ' skilgreindir ekki lglegt gildi fyrir "%s"!');
@define('USERCONF_REALNAME', 'Nafn');
@define('USERCONF_REALNAME_DESC', 'Fullt nafn hfundar. etta er nafni eins og lesendur sj a');
@define('HOTLINK_DONE', 'Skr hotlinku.<br />Bin.');
@define('ENTER_MEDIA_URL_METHOD', 'Sknarafer:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Athuga: Ef  vilt hotlinka  jn, gakktu r skuggu um a  hafir rttindi  vikomandi vefsu, ea a  eigir vefsuna. Hotlink leyfir r a nota myndir sem eru ekki  num vefjni n ess a vista r  jninum.');
@define('MEDIA_HOTLINKED', 'hotlinka');
@define('FETCH_METHOD_IMAGE', 'Skja mynd  jninn inn');
@define('FETCH_METHOD_HOTLINK', 'Hotlinka  jn');
@define('DELETE_HOTLINK_FILE', 'Eyddi hotlinkari skr, nefnd <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Sna netfng?');
@define('IMAGE_MORE_INPUT', 'Bta vi fleiri myndum');
@define('BACKEND_TITLE', 'Frekari upplsingar  vibtastillingavalmyndinni');
@define('BACKEND_TITLE_FOR_NUGGET', 'Hr geturu skilgreint streng sem er birtur  vibtarstillingasvalmyndinni samt lsingunni  HTML stubbsvibtinni. Ef  ert me marga HTML stubba me tmt meginml hjlpar etta vi a agreina stubbana hvorn fr rum.');
@define('CATEGORIES_ALLOW_SELECT', 'Leyfa gestum a skoa marga flokka  einu?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Ef essi valmguleiki er virkur verur hgt a haka vi hvern flokk  essari hliarrammavibt. Notendur geta  haka vi flokka og s frslur sem tilheyra valinu hverju sinni.');
@define('PAGE_BROWSE_PLUGINS', 'Sa %s af %s, me samtals %s vibtur.');
@define('INSTALL_CAT_PERMALINKS', 'Varanlegir hlekkir');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Skilgreinir misleg slamynstur (URL patterns) til a skilgreina varanlega hlekki fyrir bloggi itt. a er mlt me v a  notir sjlfgefna kosti hr; ef ekki ttiru a prfa a nota %id% gildi ar sem mgulegt er til a hindra Serendipity til a senda gagnagrunninum fyrirspurn til a fletta upp slinni.');
@define('INSTALL_PERMALINK', 'URL uppbygging varanlegra hlekkja sla');
@define('INSTALL_PERMALINK_DESC', 'Hr geturu skilgreint slauppbygginguna, allt fr upphafssl til ess hvar frslur kynnu a vera til staar.  getur nota breyturnar %id%, %title%, %day%, %month%, %year% og alla ara stafi.');
@define('INSTALL_PERMALINK_AUTHOR', 'Uppbygging varanlegra hlekkja sla hfundar');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Hr geturu skilgreint slauppbygginguna, allt fr upphafssl til ess hvar frslur fr kvenum hfundum kynnu a vera til staar.  getur nota breyturnar %id%, %realname%, %username%, %email% Og alla ara stafi.');
@define('INSTALL_PERMALINK_CATEGORY', 'URL uppbygging varanlegra hlekkja flokka');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hr geturu skilgreint slauppbygginguna, allt fr upphafssl til ess hvar frslur r kvenum flokkum kynnu a vera til staar.  getur nota breyturnar %id%, %name%, %parentname%, %description% og alla ara stafi.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'URL uppbygging varanlegra RSS-strauma flokka');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Hr geturu skilgreint slauppbygginguna, allt fr upphafssl til ess hvar RSS-straumar r kvenum flokkum kynnu a vera til staar.  getur nota breyturnar %id%, %name%, %description% og alla ara stafi.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Sl til skjalasafna');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Sl til skjalasafns');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Sl til flokka');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Sl til a segja upp skrift a athugasemdum');
@define('INSTALL_PERMALINK_DELETEPATH', 'Sl til a eya athugasemdum');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Sl til a samykkja athugasemdir');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Sl til RSS strauma');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Sl til stakrar vibtar');
@define('INSTALL_PERMALINK_ADMINPATH', 'Sl til stjrnkerfis');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Sl til leitar');
@define('INSTALL_CAL', 'Tegund dagatals');
@define('INSTALL_CAL_DESC', 'Veldu forsni skas dagatals');
@define('REPLY', 'Svara');
@define('USERCONF_GROUPS', 'Hpar og melimir');
@define('USERCONF_GROUPS_DESC', 'essi notandi er melimur eftirfarandi hpa. a er hgt a vera melimur fleiri en eins hps.');
@define('MANAGE_GROUPS', 'Vinna me hpa');
@define('DELETED_GROUP', 'Hpur #%d %s eytt.');
@define('CREATED_GROUP', 'Nr hpur %s hefur veri binn til');
@define('MODIFIED_GROUP', 'Eiginleikum hps %s hefur veri breytt');
@define('GROUP', 'Hpur');
@define('CREATE_NEW_GROUP', 'Ba til njan hp');
@define('DELETE_GROUP', ' ert a fara a eya hp #%d %s. Ertu viss?');
@define('USERLEVEL_OBSOLETE', 'TILKYNNING: Stjrnstigsbreytan er n einungis notu fyrir afturvirkan stuning vi vibtur og varakerfisaukenningu. Notendarttindum er n stjrna af hvaa hp notandi tilheyrir!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'ID ess straums sem  vilt birta');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner mynd');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Nafn myndar til a birta (ea skilja eftir autt fyrir teljara), stasettrar  feedburner.com, dmi: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner titill');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Titill (ef einhver) til a birta me myndinni');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner myndartexti');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Texti (ef einhver) til a birta egar msin sveimar yfir myndinni');
@define('SEARCH_TOO_SHORT', 'Leitarfyrirspurnin n verur a vera lengri en rr stafir.  getur prfa a bta vi * vi styttri or, t.d.: s9y* til a plata leitina  a nota styttri or.');
@define('INSTALL_DBPORT', 'Port gagnagrunns');
@define('INSTALL_DBPORT_DESC', 'Porti sem nota er til a tengjast vi gagnagrunnsjninn inn');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Frontend: Utanakomandi jnustur');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Frontend: Mguleikar');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Frontend: Fullkomnar vibtur');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Frontend: Sjnarmi');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Frontend: Frslutengt');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Backend: Ritill');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Backend: Notendaumsjn');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Backend: Meta upplsingar');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Backend: Forsni');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Backend: Mguleikar');
@define('PLUGIN_GROUP_IMAGES', 'Myndir');
@define('PLUGIN_GROUP_ANTISPAM', 'Spamvrn');
@define('PLUGIN_GROUP_MARKUP', 'Textasni');
@define('PLUGIN_GROUP_STATISTICS', 'Tlfri');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Fara  persnustillingar');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Breyta stjrnstigum');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Breyta "banna nskrningu frsla"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Breyta rtti til a birta frslur');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Fara  kerfisstillingar');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Fara  bloggtengdar stillingar');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Stjrna frslum');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Stjrna frslum annarra notenda');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Flytja inn frslur');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Stjrna flokkum');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Stjrna flokkum annarra notenda');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Eya flokkum');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Stjrna notendum');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Eya notendum');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Breyta stjrnstigi');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Breyta notendum sem eru  num hp(um)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Breyta notendum sem eru ekki  num hp(um)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Ba til nja notendur');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Stjrna notendahpum');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Stjrna vibtum');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Stjrna vibtum annarra notenda');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Stjrna gagnaskrm');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Stjrna gagnamppum');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Bta vi njum gagnaskrm');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Eya gagnaskrm');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Stjrna gagnastrm annarra notenda');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Skoa gagnaskrr');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Samhfa snishorn');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Stjrna athugasemdum');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Stjrna forsnium');
@define('INSTALL_BLOG_EMAIL', 'Netfang bloggkerfis');
@define('INSTALL_BLOG_EMAIL_DESC', 'etta stillir inn netfangi sem er nota sem "Fr"-hluti tsendra psta. Passau a etta s netfang sem er viurkennt af pstjni hsingarvlarinnar. Margir pstjnar synja skilaboum sem eru me ekkt netfang  "Fr"-hlutanum.');
@define('CATEGORIES_PARENT_BASE', 'Sna einungis flokka undir...');
@define('CATEGORIES_PARENT_BASE_DESC', ' getur vali yfirflokk svo a einungis undirflokkar ess flokks eru sndir.');
@define('CATEGORIES_HIDE_PARALLEL', 'Sna flokka sem eru ekki hluti af flokkstrnu');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Ef  vilt fela flokka sem eru hluti af ru flokkstr arftu a virkja etta. essi mguleiki  best rtt  sr ef notaur  samfloti vi fjlda-blogg, egar vibtin "Properties/Templates of categories" er notu.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Skoa gagnaskrr annarra notenda');
@define('CHARSET_NATIVE', 'Innlent');
@define('INSTALL_CHARSET', 'Val stafasetts (charset)');
@define('INSTALL_CHARSET_DESC', 'Hr geturu vali UTF-8 ea innlend (ISO, EUC, ...) stafasett. Sum tunguml hafa einungis UTF-8 ingar svo a a stilla stafasetti  "Innlent" mun ekki hafa nein hrif. UTF-8 er rlagt fyrir njar uppsetningar. Ekki breyta essari stillingu ef  hefur egar skr frslur me srstfum - a gti leitt til rangrar birtingar. Frekari upplsingar um etta eru  http://www.s9y.org/index.php?node=46');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Virkja vibt API hook');
@define('CALENDAR_EXTEVENT_DESC', 'Ef virt geta vibtur hengt sig  dagatali til a beina athygli a eigin atburum. Virkjau einungis ef  hefur sett inn vibtur sem urfa  essu a halda, annars minnkar etta bara afkst.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API vimt Serendipity fylgir ekki lengur me vegna trekara ryggisvandamla me etta API og a eru ekki margir sem nota a. Vegna ess arftu a setja inn XML-RPC vibtina til a nota XML-RPC API vimti. Slin sem nota ber  forritunum num mun ekki breytast - um lei og  setur inn vibtina muntu geta nota API vimti.');
@define('PERM_READ', 'Lesrttindi');
@define('PERM_WRITE', 'Skrifrttindi');

@define('PERM_DENIED', 'Ager ekki leyf.');
@define('INSTALL_ACL', 'Bta vi lesrttindum fyrir flokka');
@define('INSTALL_ACL_DESC', 'Ef virkja munu rttindi notendahpa sem  settir upp virkju egar innskrir notendur skoa bloggi itt. Ef virkja eru lesrttindi flokkanna ekki virkju en jkvu hrifin eru rlti hraari afkst kerfissins. Ef  arft ekki fjldanotenda lesrttindi er skynsamlegt a virkja etta.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Stilling stika fyrir rng fyrir valmguleika "%s". arf gagnategund af ger "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Nverandi lykilor');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Ef  breytir lykilorinu  svinu a ofan arftu a sl inn nverandi lykilor inn  etta svi.');
@define('USERCONF_CHECK_PASSWORD_ERROR', ' slst ekki inn rtt nverandi lykilor, og getur v ekki breytt lykilorinu. Njar stillingar ekki vistaar.');
@define('ERROR_XSRF', 'Vafrinn inn sendi ekki gildan HTTP-Referrer streng. etta getur hafa skapast vegna vitlaust stillts vafra/proxy jns ea vegna gagnsuflsunartilraunar (Cross Site Request Forgery, XSRF) gegn r. Beinin n klraist ekki.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Hr geturu skilgreint slauppbygginguna, allt fr upphafssl til ess hvar RSS-straumar fr kvenum notendum kynnu a vera til staar.  getur nota breyturnar %id%, %realname%, %username%, %email% og alla ara stafi.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'URL uppbygging varanlegra RSS-strauma hfundar');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'St til hfunda');
@define('AUTHORS', 'Hfundar');
@define('AUTHORS_ALLOW_SELECT', 'Leyfa gestum a birta marga hfunda  einu?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Ef essi mguleiki er virkur verur hgt a haka vi hvern hfun  essari hliarrammavibt. Notendur geta  haka vi hfunda og s frslur sem tilheyra valinu hverju sinni.');
@define('AUTHOR_PLUGIN_DESC', 'Sna lista hfunda');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Virkja Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Ef essi mguleiki er virkjaur mun vibtin nta Smarty-Templating mguleika til a sna flokkalistana. Ef  virkjar etta geturu breytt tlitinu  gegnum "plugin_categories.tpl" forsnisskrna. A virkja ennan mguleika mun hafa hrif  afkst, svo ef  arft ekki a gera neinar srsninar breytingar skaltu lta etta vera virkja.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Sna fjlda frsla  hverjum flokk?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Sna fjlda greina vi hliina  nafni hfundar?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Ef essi mguleiki er virkjaur mun fjldi greina eftir ennan hfund vera sndur vi hliina  nafni hans innan sviga.');
@define('CUSTOM_ADMIN_INTERFACE', 'Srsnii stjrnkerfi mgulegt');

@define('COMMENT_NOT_ADDED', 'Gat ekki btt athugasemd inni vi, v athugasemdir hafa anna hvort veri gerar virkar fyrir essa frslu,  slst inn leyfilegt efni, ea athugasemdin var gripin af spammvrninni.');
@define('INSTALL_TRACKREF', 'Virkja eftirlit vsara?');
@define('INSTALL_TRACKREF_DESC', 'A virkja eftirlit vsara mun sna r hvaa sur vsa  greinar nar.  dag er etta gjarnan nota af spmmurum, svo  getur gert a virkt ef  vilt.');
@define('CATEGORIES_HIDE_PARENT', 'Fela valinn yfirflokk?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Ef  takmarkar upplistun flokka vi kveinn flokk muntu sj ann yfirflokk  tlistuninni. Ef  virkjar ennan valmguleika mun nafn yfirflokksins ekki vera birt.');
@define('WARNING_NO_GROUPS_SELECTED', 'Var:  valdir ekki neina hpa. etta myndi skr ig t r notendahpastjrn og .afl. myndu num hpum ekki vera breytt.');
@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
@define('FURTHER_LINKS', 'Further Links');
@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Comment removed)');

@define('CURRENT_AUTHOR', 'Current author');

@define('WORD_NEW', 'New');
@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
@define('MEDIA_KEYWORDS', 'Media keywords');
@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
@define('MEDIA_PROP', 'Media properties');


@define('GO_ADD_PROPERTIES', 'Go & enter properties');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
@define('MEDIA_PROPERTY_TITLE', 'Title');
@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');

@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Theme/Style options');

@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');

@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Associated Date');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');

@define('MEDIA_TARGET', 'Target for this link');
@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
@define('MEDIA_ENTRY', 'Isolated Entry');
@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');

@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
@define('PLUGIN_ACTIVE', 'Active');
@define('PLUGIN_INACTIVE', 'Inactive');
@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');

@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
@define('SET_TO_MODERATED', 'Moderate');
@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
@define('CENTER', 'center');
@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');

@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
@define('BADTOKEN', 'Invalid Moderation Link'); 

@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
@define('PLUGIN_DOCUMENTATION', 'Documentation');
@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
